#
# spec file for package python-osc-lib
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-osc-lib
Version:        2.0.0
Release:        8.4.6
Summary:        OpenStackClient Library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/developer/osc-lib
Source0:        https://files.pythonhosted.org/packages/source/o/osc-lib/osc-lib-2.0.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-Babel >= 2.3.4
BuildRequires:  python3-cliff >= 2.8.0
BuildRequires:  python3-fixtures
BuildRequires:  python3-keystoneauth1 >= 3.7.0
BuildRequires:  python3-mock
BuildRequires:  python3-openstacksdk >= 0.15.0
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslo.utils >= 3.33.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-osprofiler
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-requests-mock
BuildRequires:  python3-simplejson >= 3.5.1
BuildRequires:  python3-six >= 1.10.0
BuildRequires:  python3-stestr
BuildRequires:  python3-stevedore >= 1.20.0
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
OpenStackClient (aka OSC) is a command-line client for OpenStack.  osc-lib
is a package of common support modules for writing OSC plugins.

%package -n python3-osc-lib
Summary:        OpenStackClient Library
Group:          Development/Languages/Python
Requires:       python3-Babel >= 2.3.4
Requires:       python3-cliff >= 2.8.0
Requires:       python3-keystoneauth1 >= 3.7.0
Requires:       python3-openstacksdk >= 0.15.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-pbr >= 2.0.0
Requires:       python3-simplejson >= 3.5.1
Requires:       python3-six >= 1.10.0
Requires:       python3-stevedore >= 1.20.0

%description -n python3-osc-lib
OpenStackClient (aka OSC) is a command-line client for OpenStack.  osc-lib
is a package of common support modules for writing OSC plugins.

This package contains the Python 3.x module.

%package -n python-osc-lib-doc
Summary:        Documentation for the OpenStack client library
Group:          Development/Languages/Python
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-reno
BuildRequires:  python3-sphinxcontrib-apidoc

%description -n python-osc-lib-doc
Documentation for the OpenStack client library.

%prep
%autosetup -p1 -n osc-lib-2.0.0
%py_req_cleanup

%build
%{py3_build}

%install
%{py3_install}

# generate html docs
PBR_VERSION=%{version} PYTHONPATH=. %sphinx_build -a -E -d doc/build/doctrees -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%check
python3 -m stestr.cli run

%files -n python3-osc-lib
%license LICENSE
%doc README.rst ChangeLog
%{python3_sitelib}/osc_lib
%{python3_sitelib}/*.egg-info

%files -n python-osc-lib-doc
%license LICENSE
%doc doc/build/html

%changelog
* Tue May 12 2020 cloud-devel@suse.de
- update to version 2.0.0
  - Add enhance_help kwarg to tags option generators
  - Add a release note for dropping py2
  - Update master for stable/train
  - Drop python 2.7 support and testing
  - Switch to Ussuri jobs
  - Add KeyValueAppendAction to osc-lib
* Thu Mar 12 2020 dmueller@suse.com
- switch to python 3.x only client
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 1.14.1
  - Corrent using auth_type=none in clouds.yaml
  - Add Python 3 Train unit tests
  - Add error message when occurrence Forbidden error
  - Dropping the py35 testing
  - format_dict() returns no value for None
  - Updates for OpenDev transition
  - Fix usage of NotFound exception
  - Handle nested dicts in format_dict()
  - Add FakeModule from OSC
  - Final switch to stestr
  - Move the _tag module from OSC to osc-lib
  - Cleanups to prepare for OSC 4 release
  - Update master for stable/stein
  - OpenDev Migration Patch
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.12.1
  - switch documentation job to new PTI
  - Replaced a few references to LP bugs with storyboard
  - Revert "Fixes a bug with issubclass() being called on an instance"
  - add python 3.7 unit test job
  - add lib-forward-testing-python3 test job
  - Add release note for --os-user-id fix
  - Change openstack-dev to openstack-discuss
  - Mask password when specified as an argument with a space
  - Update reno for stable/rocky
  - Remove pypy job
  - Remove PyPI downloads
  - Default to using public interface for all clients
  - Allow use of user-id as well as username for authentication
  - add python 3.6 unit test job
  - Use template for lower-constraints
  - Fix formatter handling for python 3.7
  - import zuul job settings from project-config
- remove 0001-Fix-formatter-handling-for-python-3.7.patch (upstream)
* Wed Mar  6 2019 tbechtold@suse.com
- add 0001-Fix-formatter-handling-for-python-3.7.patch (bsc#1127954)
  Fix openstack client for python 3.7
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 1.11.1
  - Use openstack.config for config and Session objects
  - Delete the output in "find_bulk" api
  - Update reno for stable/queens
  - Run OSC unit test tips jobs
  - Add OpenTracing based driver id
  - Add project lookup utils
  - Allow to use the none auth plugin
  - Add cloud to warning about domain related config
  - Stop processing requests verify args
  - Suppress subTest() expected errors
  - Zuul: Remove project name
  - Add release note link in README
  - Pass prompt_for_password to OSC_Config constructor
  - Rename python-openstacksdk to openstacksdk
  - Update .gitreview for stable/rocky
  - Update sphinx lower-constraint to match test-requirements
  - Fixes a bug with issubclass() being called on an instance
  - Trivial: Update pypi url to new url
  - fix tox python3 overrides
  - Replace autodoc with sphinxcontrib-apidoc
  - Revert "Fixes a bug with issubclass() being called on an instance"
  - Adding api_version to FakeAPP
  - Fix exception in log warning when no cloud config exists
  - Set defaults in ClientManager tests
  - Updated from global requirements
  - add lower-constraints job
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 1.9.0 (bsc#1078607)
  - Updated from global requirements
  - Fix find() interface when attr is not specified
  - Fix sorting in Python 3
  - Relocate utils tests to match the main code
* Tue Jan 30 2018 cloud-devel@suse.de
- update to version 1.8.0
  - Emit warnings to encourage cliff FormattableColumn
  - Remove -U from pip install
  - Add CLI/ENV options and documentation for keystone-to-keystone
  - --os-profile option suddenly causes trouble in unit tests
  - Update reno for stable/pike
  - Remove setting of version/release from releasenotes
  - Use converged SDK insead of os-client-config
  - Migrade legacy jobs into the repo
  - Make -tips job non-voting
  - Update the documentation link for doc migration
  - Util to calculate header and attr names based on parsed_args.columns
  - Updates for stestr
  - Consume the devstack functional jobs from OSC
  - Updated from global requirements
  - Add utils for better column handling
  - Avoid tox_install.sh for constraints support
* Mon Jan 15 2018 dmueller@suse.com
- switch to singlespec
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.7.0
  - Revert "Avoid to authenticate twice"
  - Add endpoint hook to BaseAPI
  - Follow-up to headers handler to fix find_bulk()
  - Util methods for column name backward compatibility
  - Nit: Reorder some util methods in alphabetic order
  - Update reno for stable/ocata
  - update links to docs in readme
  - Using assertIsNone() instead of assertEqual(None)
  - Avoid 'NoneType' error when format conversion
  - rearrange existing documentation to fit the new standard layout
  - Add MultiKeyValueCommaAction to osc-lib
  - turn on warning-is-error for sphinx
  - Add test methods to compare formattable column values
  - The python 3.5 is added
  - use openstackdocstheme html context
  - Change noauth strategy for plugin loading
  - Add more API support
  - Add token auth test
  - Fix find_resource exception handling on numeric names with kwargs
  - Pass ssl values through to OCC
  - Make --os-profile load from environment variables
  - switch from oslosphinx to openstackdocstheme
  - Fix shell saving OpenStackConfig object
  - Deprecate --profile and remove after Apr 2017
  - Remove log translations
  - Avoid to authenticate twice
  - Tell ClientManager when auth is required
  - Add formattable column base classes
  - Updated from global requirements
  - Optimize find_resource: do not run the same query twice
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 1.3.0:
  - Avoid string actions on non-string objects
  - Include OSC additions
  - Add deprecated_option_warning() method to Command
  - standardize release note page ordering
  - Enable release notes translation
  - Include OSC additions 2
  - Update reno for stable/newton
  - Prompt for auth options
  - Add Constraints support
  - Remove os-client-config hacks for 1.19.x and 1.20.x
  - Don't include openstack/common in flake8 exclude list
  - Clean imports in code
  - Don't call formatters on None value
  - Calls to federated service providers using Keystone-to-Keystone
  - Update docstring to match params
  - Incorrect usage message when no auth param passed
  - Improve output of supported client versions
  - Fix a tiny typo in documentation
  - Allow passing app_name and app_version for useragent
  - TrivialFix: Remove logging import unused
  - Fix version import in releasenotes
  - Add release note for security bug 1630822
  - Mask passwords in debug logs for auth_config_hook
  - TrivilalFix: Using assertIsNone() instead of assertEqual(None)
  - Updated from global requirements
  - To display image size in human friendly format
* Thu Oct  6 2016 tbechtold@suse.com
- Update _service
* Thu Sep  1 2016 tbechtold@suse.com
- update to version 1.1.0
  * Fix default handling for verify option in ClientManager
  * Updated from global requirements
* Fri Aug 26 2016 tbechtold@suse.com
- update to version 1.0.2
  * Do not add user domain options if not needed
  * Prevent null key setting for property
  * Another precedence fix
  * Add reno for osc-lib release notes management
  * Add release notes for 1.0 release
  * Fix arguemnt precedence issues with os-client-config
  * More hacks to fix broken o-c-c precedence
  * Decode argv to Unicode on py2
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 0.4.1
  * Remove unused releasenotes infrastructure
  * Remove option handling unused code
  * Use assertEqual() instead of assertDictEqual()
  * Allow shell class to be overridden in test subclass
* Fri Jul 29 2016 dmueller@suse.com
- update to 0.4.0:
  * Add Python 3.5 classifier and venv
  * Updated from global requirements
  * Fix v2 auth with v3 args present
  * trivial whitespace change to kick off docs publishing
  * Remove discover from test-requirements
* Fri Jul 22 2016 tbechtold@suse.com
- update to 0.3.0:
  * Updated from global requirements
  * Generate auth plugin options based on the name
  * Remove tempest from test-requirements.txt
  * Don't create a requests.Session for session
  * Remove old fakes
  * Updated from global requirements
* Wed Jul 13 2016 tbechtold@suse.com
- Initial packaging (version 0.2.1)
